@@ -230,38 +230,13 @@ used by AutoDB itself.
                -class=>'Class::Person',
                -collection=>'Person',
                -keys=>qq(name string, sex string, friends list(string)));
-  #@registrations=$registry->registrations;  # return all registrations
   @collections=$registry->collections;      # return all collections that have 
                                             # been registered
-#  @tables=$registry->tables;	            # return all tables needed to implement
-#                                           # all collections
-#  @tables=$registry->tables(-collection=>'Person'); # return tables needed to 
-#                                                    # implement one collection
-#  %columns=$registry->columns(-table=>$table); # return columns and SQL data types
-#                                               # for table
-
   my $saved_registry=new Class::AutoDB::Registry
          (-autodb=>$autodb,
           -object_table=>'_AutoDB_Object');# get saved registry from database
 
-  confess "New registry inconsistent with saved one" 
-     unless $registry->is_consistent($saved_registry);
-  if ($registry->is_sub($saved_registry) { # is new registry subset of saved one?
-    $registry=$saved_registry;             # then used saved one
-  } elsif  ($registry->is_different($saved_registry)) {	  
-    # get changes -- new collections and collections with new columns
-    my @new_collections=$registry->self_only_collections($saved_registry);
-    for my $collection (@new__collections) {
-        $saved_registry->create($collection);
-    }
-    my @expanded_collections=$registry->expanded_collections($saved_registry);
-    for my $collection (@expanded_collections) {
-      my $saved_collection=$saved_registry->collection($collection);
-      $saved_registry->alter($saved_collection,$collection);
-      }
-    }
-    $registry=$saved_registry;            # saved registry now reflects changes
-    $saved_registry->put;                 # store it in database for next time
+  $saved_registry->put;                 # store it in database for next time
 
   # Other commonly used methods
 
@@ -278,12 +253,12 @@ is meant to define a database), but there can be two versions of it.
 
 1.  An in-memory version generated by calls to the 'register'
     method.  This method is usually called automatically when
-    AutoClass processes %AUTO_PERSISTENCE declarations from classes as
+    AutoClass processes %AUTODB declarations from classes as
     they are loaded.  The 'register' method can also be called
     explicitly at runtime.
 
 2.  A database version. The stored version is supposed to reflect
-    the real structure of the AutoPeristence database.  (Someday we
+    the real structure of the AutoDB database.  (Someday we
     will provide a method for confirming this.)
 
 Before the AutoDB mechanism can run, it must ensure that the
@@ -381,55 +356,6 @@ $object->xxx($new_value); To clear it, say $object->xxx(undef);
  Access  : read-only (no mutator provided even for internal use)
 
 
-=head2 registrations
-
- Title   : register
- Usage   : $registry->register(
-                  -class=>'Class::Person',
-                  -collection=>'Person',
-                  -keys=>qq(name string, sex string, friends list(string)));
- Function: Registers a class/collection with the system. 
- Args    : -class       => name of class being registered
-           -collection  => name of collection that will hold objects, or
-                           ARRAY of collection names
-           -collections => synonym for -collection
-           -keys        => specification of search keys for collection(s) -- see below
-           -skip        => ARRAY of attributes that will not be stored.  This is
-                           useful for objects that contain computed values or other 
-                           information of a transient nature.
-           -auto_get    => ARRAY of attributes that are automatically retrieved
-                           when objects of this class are retrieved. These should be
-                           attributes that refer to other auto-persistent objects.
-                           This useful in cases where there are attributes that are 
-                           used so often that it makes sense to retrieve them as soon 
-                           as possible.
-  Returns : Class::AutoDB::Registration object
-
-The 'keys' parameter consists of attribute, data type pairs.  Each
-attribute is generally an attribute defined in the AutoClass
-@AUTO_ATTRIBUTES or @OTHER_ATTRIBUTES variables.  (Technically, it's
-the name of a method that can be called with no arguments.) The value
-of an attribute must be a scalar, an object reference, or an ARRAY (or
-list) of such values.) 
-
-The data type can be 'string', 'integer', 'float', 'object', any legal
-MySQL column type, or the phrase list(<data type>), eg,
-'list(integer)'.
-
-NB: At present, only our special data types ('string', 'integer',
-'float', 'object') are supported. These can be abbreviated.
-
-The 'keys' parameter can also be an array of attribute names, eg,
-
-    -keys=>[qw(name sex)]
-
-in which case the data type of each attribute is assumed to be
-'string'.  This works in many cases even if the data is really
-numeric as discussed in the Persistence Model section.
-
-The types 'object' and 'list(object)' only work for objects whose
-persistence is managed by AutoDB.
-
 =head2 collections
 
  Title   : collections
@@ -465,15 +391,6 @@ contains a collection of the same name, the information from the new
 collection is merged with the existing collection.  It is an error if
 the merged information is not consistent.
 
-#=head2 tables
-
-# Usage   : $tables=$registry->tables;
-#          -- OR --
-#           @tables=$registry->tables;
-# Function: Return tables needed to implement registry's collections
-# Args    : None
-# Returns : array or ARRAY ref of Class::AutoDB::Table objects
-
 =head2 Operations that touch the database
 
 These methods read or write the actual database structure. They are only
@@ -549,106 +466,4 @@ IT is an error if the registry does not already exist.
  Args    : Nothing
  Returns : Object id for registry (always the same at present)
 
-=head2 Comparison methods
-
-These methods compare two registries and report on differences.  Since
-the underlying comparison process is relatively slow, comparison
-results are cached within the registry.  This shoudld be trasparent in
-normal use, but you must call cmp_reset if you wish to force a
-comparison to be redone, eg if you change the 'other_registry'.
-
- Title   : cmp_reset
- Usage   : $registry->cmp_status
-           -- OR --
-           $registry->cmp_status($other_registry)
- Function: Reset comparison cache for one or all other registries
- Args    : registry being compared with this one (optional)
- Returns : true/false values
-
- Title   : self_only_collections
- Usage   : @collections=$registry->self_only_collections($other_registry);
-          -- OR --
-           $collections=$$registry->self_only_collections($other_registry);
- Function: Return collections present in this registry but not other
- Args    : registry being compared with this one
- Returns : array or ARRAY ref of Class::AutoDB::Collection objects
-
- Title   : other_only_collections
- Usage   : @collections=$registry->other_only_collections($other_registry);
-          -- OR --
-           $collections=$$registry->other_only_collections($other_registry);
- Function: Return collections present in other registry but not this one
- Args    : registry being compared with this one
- Returns : array or ARRAY ref of Class::AutoDB::Collection objects
-
- Title   : expanded_collections
- Usage   : @collections=$registry->expanded_collections($other_registry);
-          -- OR --
-           $collections=$$registry->expanded_collections($other_registry);
- Function: Return collections that have additional search keys in this registry 
-           than the other.
- Args    : registry being compared with this one
- Returns : array or ARRAY ref of Class::AutoDB::Collection objects
-
- Title   : shrunk_collections
- Usage   : @collections=$registry->shrunk_collections($other_registry);
-          -- OR --
-           $collections=$$registry->shrunk_collections($other_registry);
- Function: Return collections that are missing search keys in this registry 
-           compared to the other.
- Args    : registry being compared with this one
- Returns : array or ARRAY ref of Class::AutoDB::Collection objects
-
- Title   : is_consistent
- Usage   : $status=$registry->is_inconsistent($other_registry)
- Function: Check if registries are consistent
- Args    : registry being compared with this one
- Returns : true/false values
-
- Title   : is_inconsistent
- Usage   : $status=$registry->is_inconsistent($other_registry)
- Function: Check if registries are inconsistent
- Args    : registry being compared with this one
- Returns : true/false values
-
- Title   : is_equivalent
- Usage   : $status=$registry->is_equivalent($other_registry)
- Function: Check if registries are equivalent.
- Args    : registry being compared with this one
- Returns : true/false values
-
- Title   : is_different
- Usage   : $status=$registry->is_different($other_registry)
- Function: Checkif registries are not equivalent.
- Args    : registry being compared with this one
- Returns : true/false values
-
- Title   : is_sub
- Usage   : $status=$registry->is_sub($other_registry)
- Function: Check if this registry is subset of other.  Note: equivalent is 
-           considered subset.
- Args    : registry being compared with this one
- Returns : true/false values
-
- Title   : is_super
- Usage   : $status=$registry->is_super($other_registry)
- Function: Check if this registry is superset of other. Note: equivalent is 
-           considered subset.
- Args    : registry being compared with this one
- Returns : true/false values
-
-# Title   : is_expanded
-# Usage   : $status=$registry->is_expanded($other_registry)
-# Function: Check if this registry contains collections that are expanded
-#           relative to the other. 
-# Args    : registry being compared with this one
-# Returns : true/false values
-
-# Title   : is_shrunk
-# Usage   : $status=$registry->is_shrunk($other_registry)
-# Function: Check if this registry contains collections that are shrunk
-#           relative to the other. 
-# Args    : registry being compared with this one
-# Returns : true/false values
-
 =cut
